@@ -33,9 +33,9 @@ def exception_handler(func):
             frm = inspect.trace()[-1]
             mod = inspect.getmodule(frm[0])
             modname = mod.__name__ if mod else frm[1]
-            error_message = {'Exception': {'detail': {'errorcode': f'{modname}.{type(e).__name__}'}, 'exceptionstring': f'{e}'}}
-            # sys.exit(f'An exception of type {type(e).__name__} occurred. Arguments:\n{e}')
-            sys.exit(json.dumps(error_message, indent=4))
+            # error_message = {'Exception': {'detail': {'errorcode': f'{modname}.{type(e).__name__}'}, 'exceptionstring': f'{e}'}}
+            sys.exit(f'An exception of type {modname}.{type(e).__name__} occurred. Arguments:\n{e}')
+            # sys.exit(json.dumps(error_message, indent=2))
         except KeyboardInterrupt as ki:
             console.echo()
             sys.exit(130)
