@@ -36,9 +36,7 @@ def permissions():
 
 
 def _create_permissions(username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs):
-    return (
-        Permissions(gen_auth(username, password, mfa_secret, token, zonename), org, name).create_permissions(body).text
-    )
+    return Permissions(gen_auth(username, password, mfa_secret, token, zonename), org, name).create_permissions(body).text
 
 
 @permissions.command(help='Create permissions for a role.')
@@ -51,20 +49,7 @@ def create(*args, **kwargs):
     console.echo(_create_permissions(*args, **kwargs))
 
 
-def _team_permissions(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    file,
-    placeholder_key=None,
-    placeholder_value="",
-    **kwargs
-):
+def _team_permissions(username, password, mfa_secret, token, zonename, org, profile, name, file, placeholder_key=None, placeholder_value="", **kwargs):
     return (
         Permissions(gen_auth(username, password, mfa_secret, token, zonename), org, name)
         .team_permissions(file, placeholder_key=placeholder_key, placeholder_value=placeholder_value)
@@ -77,31 +62,14 @@ def _team_permissions(
 @common_silent_options
 @common_verbose_options
 @click.option('-n', '--name', help='the role name', required=True)
-@click.option(
-    '-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True
-)
+@click.option('-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True)
 @click.option('--placeholder-key', default=None, help='placeholder key to replace with a placeholder value')
-@click.option(
-    '--placeholder-value', default="", show_default=True, help='placeholder value to replace placeholder key.'
-)
+@click.option('--placeholder-value', default="", show_default=True, help='placeholder value to replace placeholder key.')
 def template(*args, **kwargs):
     console.echo(_team_permissions(*args, **kwargs))
 
 
-def _get_permissions(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    format,
-    showindex=False,
-    tablefmt='plain',
-    **kwargs
-):
+def _get_permissions(username, password, mfa_secret, token, zonename, org, profile, name, format, showindex=False, tablefmt='plain', **kwargs):
     return Permissions(gen_auth(username, password, mfa_secret, token, zonename), org, name).get_permissions(
         formatted=True, format='text' if format == 'json' else format, showindex=showindex, tablefmt=tablefmt
     )
@@ -113,19 +81,10 @@ def _get_permissions(
 @common_verbose_options
 @click.option('-n', '--name', help='name', required=True)
 # @click.option("-j", "--json", help="display json output when using -r flag", default="table")
-@click.option(
-    '--format',
-    help='defines how to format output',
-    default='table',
-    type=click.Choice(['json', 'table'], case_sensitive=False),
-)
+@click.option('--format', help='defines how to format output', default='table', type=click.Choice(['json', 'table'], case_sensitive=False))
 @click.option('--showindex/--no-showindex', default=False)
 @click.option(
-    '--tablefmt',
-    help='defines how the table is formatted',
-    type=click.Choice(TABLEFMT_CHOICES, case_sensitive=False),
-    default='plain',
-    show_default=True,
+    '--tablefmt', help='defines how the table is formatted', type=click.Choice(TABLEFMT_CHOICES, case_sensitive=False), default='plain', show_default=True
 )
 def get(*args, **kwargs):
     console.echo(_get_permissions(*args, **kwargs))
